#
# spec file for package obs-service-tar_scm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?fedora_version}%{?rhel}
%define _pkg_base %nil
%else
%define _pkg_base -base
%endif

%define flavor %nil
%if "%{flavor}" == ""
%define nsuffix %nil
%else
%define nsuffix -test
%endif

%if 0%{?suse_version} && 0%{?suse_version} >= 1220 && "%{flavor}" == "test"
%bcond_without obs_scm_testsuite
%else
%bcond_with    obs_scm_testsuite
%endif

# special guard for flavor test, yet --without test being specified
%if "%{flavor}" == "test" && %{without obs_scm_testsuite}
ExclusiveArch:  skip-build
%endif

%if 0%{?suse_version} >= 1315 || 0%{?fedora_version} >= 29 || 0%{?rhel} >= 8
%bcond_without python3
%else
%bcond_with    python3
%endif

# This list probably needs to be extended
# logic seems to be if python < 2.7 ; then needs_external_argparse ; fi
%if (0%{?centos_version} == 6) || (0%{?suse_version} && 0%{?suse_version} < 1315) || (0%{?fedora_version} && 0%{?fedora_version} < 26)
%bcond_without needs_external_argparse
%else
%bcond_with    needs_external_argparse
%endif

%if %{with python3}
%define use_python python3
%define use_test   test3
%else
%define use_python python
%define use_test   test
%endif

%if 0%{?suse_version}
%define pyyaml_package %{use_python}-PyYAML
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150100
%define locale_package glibc-locale-base
%else
%define locale_package glibc-locale
%endif
%endif

%if 0%{?fedora_version} || 0%{?rhel}
%if 0%{?fedora_version} >= 29 || 0%{?rhel} >= 8
%define pyyaml_package %{use_python}-PyYAML
%else
%define pyyaml_package PyYAML
%endif

%if 0%{?fedora_version} >= 24 || 0%{?rhel} >= 8
%define locale_package glibc-langpack-en
%else
%define locale_package glibc-common
%endif
%endif

%if 0%{?mageia} || 0%{?mandriva_version}
%define pyyaml_package python-yaml
%define locale_package locales
%endif

# Mageia 8 has package names python-*
# but requires python3 in shebang
%if 0%{?mageia} >= 8 || 0%{?rhel} >= 8
%define python_path %{_bindir}/python3
%else
%define python_path %{_bindir}/%{use_python}
%endif

# avoid code duplication
%define scm_common_dep                                          \
Requires:       obs-service-obs_scm-common = %version-%release  \
%{nil}

%define scm_dependencies                                        \
Requires:       git-core                                        \
%if 0%{?suse_version} >= 1315                                   \
Recommends:     obs-service-download_files                      \
Recommends:     %{use_python}-keyring                           \
Recommends:     %{use_python}-keyrings.alt                      \
Suggests:       bzr                                             \
Suggests:       mercurial                                       \
Suggests:       subversion                                      \
%endif                                                          \
%{nil}

######## END OF MACROS AND FUN ###################################

%define pkg_name obs-service-tar_scm
Name:           %{pkg_name}%{nsuffix}
VCS: https://src.suse.de/SLFO-pool/obs-service-tar_scm#13f2361f92528146ca4e3d374abb193d9bb1f270cbab5a05dd2c713c8c1d0888
%define version_unconverted 0.10.46
Version:        0.10.46
Release:        160000.1.5
Summary:        An OBS source service: create tar ball from svn/git/hg
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/openSUSE/obs-service-tar_scm
Source:         %{pkg_name}-%{version}.tar.gz

# Fix build on Ubuntu by disabling mercurial tests, not applied in rpm
# based distributions
#Patch0:         0001-Debianization-disable-running-mercurial-tests.patch

%if %{with obs_scm_testsuite}
BuildRequires:  %{locale_package}
BuildRequires:  %{pkg_name} = %{version}
BuildRequires:  %{use_python}-keyring
BuildRequires:  %{use_python}-keyrings.alt
BuildRequires:  %{use_python}-six
BuildRequires:  bzr
BuildRequires:  git-core
BuildRequires:  gpg
BuildRequires:  mercurial
BuildRequires:  subversion
%if !%{with python3}
BuildRequires:  %{use_python}-mock
%endif
%endif

BuildRequires:  %{locale_package}
BuildRequires:  %{pyyaml_package}
%if %{with needs_external_argparse}
BuildRequires:  %{use_python}-argparse
%endif
BuildRequires:  %{use_python}-dateutil
# Why do we need this? we dont use it as runtime requires later
BuildRequires:  %{use_python}-lxml

%if %{with python3}
BuildRequires:  %{use_python}%{_pkg_base}
# Fix missing Requires in python3-pbr in Leap42.3
BuildRequires:  %{use_python}-setuptools
%if 0%{?suse_version}
BuildRequires:  python-rpm-macros
%endif
%else
BuildRequires:  python >= 2.6
%endif
%scm_common_dep
%scm_dependencies
#
#
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       %{python_path}

%description
This is a source service for openSUSE Build Service.

It supports downloading from svn, git, hg and bzr repositories.

%package -n     obs-service-obs_scm-common
Summary:        Common parts of SCM handling services
Group:          Development/Tools/Building
Requires:       %{locale_package}
Requires:       %{pyyaml_package}
Requires:       %{use_python}-dateutil
%if %{with needs_external_argparse}
Requires:       %{use_python}-argparse
%endif

%description -n obs-service-obs_scm-common
This is a source service for openSUSE Build Service.

It supports downloading from svn, git, hg and bzr repositories.

This package holds the shared files for different services.

%package -n     obs-service-tar
Summary:        Creates a tar archive from local directory
Group:          Development/Tools/Building
Provides:       obs-service-tar_scm:/usr/lib/obs/service/tar.service
%scm_common_dep

%description -n obs-service-tar
Creates a tar archive from local directory

%package -n     obs-service-obs_scm
Summary:        Creates a OBS cpio from a remote SCM resource
Group:          Development/Tools/Building
Provides:       obs-service-tar_scm:/usr/lib/obs/service/obs_scm.service
%scm_common_dep
%scm_dependencies

%description -n obs-service-obs_scm
Creates a OBS cpio from a remote SCM resource.

This can be used to work directly in local git checkout and can be packaged
into a tar ball during build time.

%package -n     obs-service-appimage
Summary:        Handles source downloads defined in appimage.yml files
Group:          Development/Tools/Building
%scm_common_dep
%scm_dependencies

%description -n obs-service-appimage
Experimental appimage support: This parses appimage.yml files for SCM
resources and packages them.

%package -n     obs-service-snapcraft
Summary:        Handles source downloads defined in snapcraft.yaml files
Group:          Development/Tools/Building
Provides:       obs-service-tar_scm:/usr/lib/obs/service/snapcraft.service
%scm_common_dep
%scm_dependencies

%description -n obs-service-snapcraft
Experimental snapcraft support: This parses snapcraft.yaml files for SCM
resources and packages them.

%if 0%{?enable_gbp}
%package -n     obs-service-gbp
Summary:        Creates Debian source artefacts from a Git repository
Group:          Development/Tools/Building
Requires:       git-buildpackage >= 0.6.0
Requires:       obs-service-obs_scm-common = %version-%release
%if 0%{?enable_gbp}
Provides:       obs-service-tar_scm:/usr/lib/obs/service/obs_gbp.service
%endif

%description -n obs-service-gbp
Debian git-buildpackage workflow support: uses gbp to create Debian
source artefacts (.dsc, .origin.tar.gz and .debian.tar.gz if non-native).
%endif

%prep
%setup -q -n obs-service-tar_scm-%version

%build

%install
%if %{without obs_scm_testsuite}
make install DESTDIR="%{buildroot}" PREFIX="%{_prefix}" SYSCFG="%{_sysconfdir}" PYTHON="%{python_path}" WITH_GBP="%{enable_gbp}"
%if %{with python3}
# Doing %%python3_fix_shebang_path old fashioned way for the backward compatibility
sed -i "1s@#\\!.*python\S*@#\\!$(realpath %__python3)@" \
    %{buildroot}%{_prefix}/lib/obs/service/tar_scm
%endif
%else

# moved conditional to the top as it helps to have it all in one place and only rely on the bcond_with here.
%check
# No need to run PEP8 tests here; that would require a potentially
# brittle BuildRequires: python-pep8, and any style issues are already
# caught by Travis CI.
make %{use_test}
%endif

%if %{without obs_scm_testsuite}
%files
%defattr(-,root,root)
%{_prefix}/lib/obs/service/tar_scm.service

%files -n obs-service-obs_scm-common
%defattr(-,root,root)
%license COPYING
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/TarSCM
%{_prefix}/lib/obs/service/tar_scm
%dir %{_sysconfdir}/obs
%dir %{_sysconfdir}/obs/services
%verify (not user group) %dir %{_sysconfdir}/obs/services/tar_scm.d
%config(noreplace) %{_sysconfdir}/obs/services/*
%ghost %dir %{_sysconfdir}/obs/services/tar_scm.d/python_keyring

%files -n obs-service-tar
%defattr(-,root,root)
%{_prefix}/lib/obs/service/tar
%{_prefix}/lib/obs/service/tar.service

%files -n obs-service-obs_scm
%defattr(-,root,root)
%{_prefix}/lib/obs/service/obs_scm
%{_prefix}/lib/obs/service/obs_scm.service

%files -n obs-service-appimage
%defattr(-,root,root)
%{_prefix}/lib/obs/service/appimage*

%files -n obs-service-snapcraft
%defattr(-,root,root)
%{_prefix}/lib/obs/service/snapcraft*

%if 0%{?enable_gbp}
%files -n obs-service-gbp
%defattr(-,root,root)
%{_prefix}/lib/obs/service/obs_gbp*
%endif
%endif

%changelog
* Thu Aug  1 2024 adrian@suse.de
- Update to version 0.10.46:
  * [dist] fix BuildRequires for older distros like SLE12
* Thu Aug  1 2024 adrian@suse.de
- Update to version 0.10.45:
  * [dist] fix shebang substitution in spec for py2
* Wed Jul 31 2024 adrian@suse.de
- Update to version 0.10.44:
  * import submit request change
  * Support updating submodules to main branch
  * do not skip "--reference" if package-meta ...
  * cpio: Do not follow symlinks in 'touch'
  * Support URL hostname in keyring
  * gbp: use --git-export
  * Update debian/changelog for 0.10.43
  * disable compile python in debian package
  * update dist/debian.dsc to match debian packaging
  * Update debian debhelper dependency
  * Fix description-synopsis-starts-with-article
  * Fix priority-extra-is-replaced-by-priority-optional
  * Debian compat from 8 to 10
  * Debian X-Python version no longer needed
  * Fix Lintian error about missing python3 dep
  * enable the GBP service
  * Fixed filtering of include/exclude when topdir has escape characters.
  * Fix setting svn credentials in the command line
* Wed Jul 31 2024 adrian@suse.de
- update to version 0.10.44:
  * Support updating submodules to main branch
  * Debian packaging for gbp service
  * do not skip "--reference" if package-meta is enabled and git's partial clone is used.
  * Fixed filtering of include/exclude when topdir has escape characters.
  * Fix setting svn credentials in the command line
  * cpio: Do not follow symlinks in 'touch'
  * Support URL hostname in keyring
  * debian package updates
* Thu Jul 25 2024 bjorn.lie@gmail.com
- "Downgrade" bzr, mercurial and subversion Recommends to Suggests.
* Fri Jun 14 2024 mcepl@cepl.eu
- Fix shebang of the script to use the explicit version of Python
  (bsc#1212476).
* Wed Feb 21 2024 adrian@suse.de
- Update to version 0.10.43:
  * Allow to use "tar" service also standalone.
* Wed Jan 17 2024 dmueller@suse.com
- add support for AL2023
* Thu Jul 20 2023 FSchreiner@suse.com
- Update to version 0.10.41:
  * fix for python2
* Tue Jul 18 2023 FSchreiner@suse.com
- Update to version 0.10.40:
  * [dist] updated debian changelog
  * Add Python 3.12 to GitHub Actions
  * Switch from ConfigParser.readfp to ConfigParser.read_string
* Wed Jul  5 2023 dmueller@suse.com
- Update to version 0.10.39:
  * Add gpg as a dependency (needed for gpg validation)
* Wed Jul  5 2023 dmueller@suse.com
- Update to version 0.10.38:
  * Python 2 is no longer supported by GitHub actions, stop testing it
  * FD leak / flake8 / py311 fixes
  * updated debian files
  * disabled pylint 'no-member' because of false positives in py311
  * removed unittest2 from BuildRequires in spec
  * fixed fixtures and new Exception class
  * updated KankuFile to Tumbleweed and removed python2 tests
* Fri May 19 2023 adrian@suse.de
- Update to version 0.10.36:
  * fix broken tar ball from 0.10.35 release
* Fri May 19 2023 adrian@suse.de
- Update to version 0.10.35
  * Avoid getting confused by _scmsync.obsinfo files
* Thu Nov  3 2022 FSchreiner@suse.com
- Update to version 0.10.34.1667392550.026bf0e:
  * Fix testing in GH actions
  * make linters happy again
  * new find_latest_signed_commit algorithm
* Wed Sep 28 2022 FSchreiner@suse.com
- Update to version 0.10.33.1664344889.48d1960:
  * check if lock is older than 24 hours
* Fri Sep  9 2022 FSchreiner@suse.com
- Update to version 0.10.32.1662712308.31d1884:
  * [dist] added Requires to python_path
  * improve tar service to handle multiple obsinfo files to create tarball from obscpio
  * new ENV 'TAR_SCM_SKIP_CLEANUP' to make test development/debugging easier
  * staple pylint version lower than 2.14 because of breaking changes in config
  * do not use python mock
  * fix pylint errors in commontests.py
  * Fixed testing
  * use extra cache dir for partial clone
  * fix cache update in case of partial clone
  * disable partial clone when subdir is set
  * do not set default subdir to '.'
  * fixes to pass pylint
  * enable partial clone feature in git scm
  * partial clone feature
  * simplify locking to avoid race conditions
  * TarSCM.cli: set some defaults to make usage in testing easier
  * unlink .lock file after unlocking the cache
* Thu Jan 13 2022 FSchreiner@suse.com
- Update to version 0.10.30.1641993356.a87e7af:
  * Simplifiy conditions for all rhel like distros
  * Changed gendered pronoun to be gender neutral
* Wed Jan 12 2022 FSchreiner@suse.com
- Update to version 0.10.30.1641990734.bdad8f9:
  * fixes for python2.7 compatibility
  * fix test cases
  * fix various linter problems with pylint 2.11.1
  * disable consider-using-f-string in pylint
  * added TC for _stash_pop_required
  * assertTarIsDeeply now more verbose in case of failure
  * remove tearDown/Trace from testenv.py
  * fix regression to keep local changes when running in osc
  * various fixes to make linter happy
  * fix tests for python 2.7
* Thu Dec 23 2021 FSchreiner@suse.com
- Update to version 0.10.29.1634038025.85bfc3f:
  * fix test cases
  * fix various linter problems with pylint 2.11.1
  * disable consider-using-f-string in pylint
  * added TC for _stash_pop_required
  * assertTarIsDeeply now more verbose in case of failure
  * remove tearDown/Trace from testenv.py
  * fix regression to keep local changes when running in osc
* Mon Sep 20 2021 FSchreiner@suse.com
- Update to version 0.10.28.1632141620.a8837d3:
  * fix missing "checkout" when running in osc
  * fix breakage on version detection
  * change locale
* Wed Jul 14 2021 FSchreiner@suse.com
- Update to version 0.10.27.1626072657.0fb7a03:
  * [ci] enhanced github actions for multiple python versions
  * Create main.yml
  * Change date format from short to %%Y%%m%%d.
* Mon Jun 21 2021 FSchreiner@suse.com
- Update to version 0.10.26.1624258505.aed4969:
  * almalinux in spec file
  * fix include filters for obscpio files
  * fix python interpreter for mageia 8
  * TarScm: use owner/group root in  .obscpio files
* Tue Jun 15 2021 FSchreiner@suse.com
- Update to version 0.10.26.1623775884.87f49a8:
  * fixed include/exclude filtering
  * add '--' to git log command if file/dir equal revision exists
  * add '--source' to git log command
  * disabled consider-using-with in .pylint*rc
  * package .gitignore files
  * Fix version _none_ generate tarball with '-'
  * Prevent KeyError in check_for_branch_request method
  * removed skipped test case (obsolete since 5 yrs)
  * testing for obscpio/obsinfo
  * fix regression - obsinfo included the version string
  * Revert "remove useless variables"
  * remove useless variables
  * added param --without-version
  * extracted dstname to _dstname
  * cleanup TarSCM/tasks.py for pylint
  * add date/time to logging output for better debugging
  * Fix typos
* Fri Mar 12 2021 FSchreiner@suse.com
- Update to version 0.10.22.1615538418.07a353d:
  * Fix filelist: align config(noreplace) usage with obs-service-download_files
  * Support gitlab/github merge requests
* Wed Feb 10 2021 FSchreiner@suse.com
- Update to version 0.10.21.1612422695.2fdf897:
  * fixes boo#1127353
  * fixes boo#1168573
  * activate pylint3.8 and fixed false positives
  * don`t sanitize version if versionrewrite_pattern is set
* Mon Feb  1 2021 FSchreiner@suse.com
- Update to version 0.10.20.1606128060.135ac94:
  * fix build for CentOS adn RHEL 8
  * filter dirs with "include" filter option
* Wed Nov 11 2020 FSchreiner@suse.com
- Update to version 0.10.19.1605080719.3b79112:
  * [dist] prefer python3 over python2
* Tue Nov 10 2020 FSchreiner@suse.com
- Update to version 0.10.18.1600256320.569e5be:
  * add license file (issue 257)
  * additional option verification
  * new option '--maintainers-asc' and '--last-signed-tag'
  * new option '--latest-signed-commit'
  * Remove superflous ')' in an error message.
* Mon Jul 20 2020 FSchreiner@suse.com
- Update to version 0.10.16.1595259906.d3308f5:
  * [dist] updated debian control file for use in OBS
* Mon Jul 20 2020 FSchreiner@suse.com
- Update to version 0.10.16.1595245235.15a0df2:
  * Build with python 3 for Debian and Ubuntu
  * [doc] added allowed urls in documentation of tar_scm.service
* Wed Jun  3 2020 pgajdos@suse.com
- remove unused unittest2 dependency
* Fri May 29 2020 FSchreiner@suse.com
- Update to version 0.10.16.1590752286.5c27247:
  * [dist] fix for gbp/fedora (python*-base)
  * fix situation when revision has been modified in _service
* Thu May  7 2020 FSchreiner@suse.com
- Update to version 0.10.15.1588842879.5c43eef:
  * dist: Convert to multibuild; run test suite in a separate flavor
* Wed Apr 29 2020 FSchreiner@suse.com
- Update to version 0.10.15.1588146746.5cfeeb8:
  * fix #boo 1168573 (obsservicerun,obsrun) not exists in client side installation
  * Update debian/changelog for latest version
  * Helpers: when a command fail, print the command itself too with its output
  * git: add support for @PARENT_TAG@ in revision
  * Fix build on non-openSUSE distro
* Tue Mar 17 2020 FSchreiner@suse.com
- Update to version 0.10.14.1584435160.d912143:
  * [dist] don't install gbp files by default
  * [dist] remove python-keyring* from dependcies
  * [dist] make gbp switchable in spec file
* Tue Mar 10 2020 FSchreiner@suse.com
- Update to version 0.10.14.1583853599.ccbb399:
  * support server side credentials for SCM repos
* Fri Feb 28 2020 adrian@suse.de
- Update to version 0.10.12.1582901608.a1c02c1:
  * simplify osc git update case a lot
  * fixing revision usage on a commit hash
* Wed Feb 26 2020 FSchreiner@suse.com
- Update to version 0.10.12.1582709176.d82a692:
  * fix lost commits on local run
  * fix breakage when working on a specific tag/commit
  * git-lfs should not be mandatory as tar_scm will never use it
  * Allow use of git-lfs only when running obs_scm
  * Document _none_ special version in .service
  * Version cleanup: don't strip hyphen when building Debian packages
  * Add new archive option for Debian: git-buildpackage
  * call git stash with LANG=C
  * improved comment for method get_changesrevision
  * Add debian package dep to git-lfs
  * Implement git LFS blobs retrieval
* Fri Jan 24 2020 FSchreiner@suse.com
- Update to version 0.10.11.1579870213.888e79c:
  * Add testcase for appimage with empty build section
  * Handle missing build entry in appimage.yml
  * Fix --mirror argument position for git clone
  * Re-enable compatibility with Python 2.6
  * fix decoding for locale -a containg non-ASCII
  * update_cache in git now does merge
  * prefer local branch over remote
  * added UnicodeDecodeError to exeption list in archive.py
  * fetch rev explicitly if using CACHEDIRECTORY and rev could not be found
  * tar_scm.service.in: Add example to match-tag.
* Tue Oct  1 2019 jgonzalez@suse.com
- Fix building and installation for CentOS8, RHEL8 and RES8
* Thu Aug 22 2019 FSchreiner@suse.com
- Update to version 0.10.10.1566390389.9f923f8:
  * Revert "Merge pull request #323 from e4t/master"
  * Make service 'tar' work with a cachedir as well
  * Fix unit tests for modified scm directory handling
  * Append '_service' to repository directory
  * separate language and encoding
  * git: really print the error message
  * tar_scm.service: fix exclude documentation
  * Don`t break testsuite if cwd contains colons
  * disabling hg tests in travis
* Wed Jun  5 2019 FSchreiner@suse.com
- Fixes boo#1138377
- Update to version 0.10.9.1559745964.22c86cd:
  * [dist] python3 for SLE12 and openSUSE 42.3
  * [dist] enable python3 in SLE >= 12
  * fix encoding error for surrogates
  * glibc-common was used up to FC23 and RHEL7
  * Compile python files before install
  * change order in GNUMakefile to prefer python3
  * More thorought spec file cleanup
  * predefine python version in spec file for GNUMAkefile
  * [dist] spec file: python3 only and multidist
  * Git also uses the LANGUAGE variable
  * centos_version and rhel_version are triple digits
  * Minimize diff with the version in openSUSE:Tools
  * Fix the logic to pick the locale package on Fedora
  * Forgot the guard 0 in one conditional
  * Require packages to get the en_US.UTF-8 locales
  * enforce bytes for cpio file list
* Tue Jun  4 2019 FSchreiner@suse.com
- Update to version 0.10.9.1559647449.d965035:
  * [dist] enable python3 in SLE >= 12
* Wed May  8 2019 jgonzalez@suse.com
- Require external argparse for RHEL6
* Tue May  7 2019 FSchreiner@suse.com
- Update to version 0.10.9.1557261720.32a1cdb:
  * fix encoding error for surrogates
  * glibc-common was used up to FC23 and RHEL7
* Fri May  3 2019 FSchreiner@suse.com
- Update to version 0.10.8.1556896538.0693a62:
  * Compile python files before install
  * change order in GNUMakefile to prefer python3
  * More thorought spec file cleanup
  * predefine python version in spec file for GNUMAkefile
* Fri Apr 26 2019 mrueckert@suse.de
- the current guessing code is finding python2 and then uses that,
  because python2 still seems to be available in the build env,
  as we already know which python version we want we can just pass
  the path to make and skip the whole guessing.
* Fri Apr 26 2019 FSchreiner@suse.com
- Update to version 0.10.7.1556277536.7e9915a:
  * [dist] spec file: python3 only and multidist
  * Git also uses the LANGUAGE variable
  * centos_version and rhel_version are triple digits
  * Minimize diff with the version in openSUSE:Tools
  * Fix the logic to pick the locale package on Fedora
  * Forgot the guard 0 in one conditional
* Tue Apr  9 2019 mrueckert@suse.de
- centos_version and rhel_version are triple digits
* Tue Apr  9 2019 mrueckert@suse.de
- locally apply fixes from
  https://github.com/openSUSE/obs-service-tar_scm/pull/298
* Fri Mar 29 2019 jgonzalez@suse.com
- Change requirement locale_package to glibc-common to fix building
  for CentOS6 and CentOS7
* Wed Mar  6 2019 adrian@suse.de
- Update to version 0.10.6.1551887937.e42c270:
  * Require packages to get the en_US.UTF-8 locales
* Fri Mar  1 2019 FSchreiner@suse.com
- Update to version 0.10.6.1551448746.2759df2:
  * enforce bytes for cpio file list
  * fixes boo#1127907
* Wed Feb 27 2019 FSchreiner@suse.com
- Update to version 0.10.5.1551309990.79898c7:
  * Prefer UTF-8 locale as output format for changes
* Wed Feb 27 2019 FSchreiner@suse.com
- Update to version 0.10.4.1551193322.b7a79f4:
  * added KankuFile
  * fix problems with unicode source files
  * added python-six to Requires in specfile
  * better encoding handling
* Thu Feb 21 2019 FSchreiner@suse.com
- Update to version 0.10.1.1550758451.f88bd41:
  * fixes bsc#1082696 and bsc#1076410
  * more fixes py3 unicode
  * fix unicode in containers
* Wed Feb 20 2019 FSchreiner@suse.com
- Update to version 0.10.0.1550647779.25999e8:
  * fix spec for RH/Fedora - glibc-locale -> glibc-common
* Tue Feb 19 2019 FSchreiner@suse.com
- Update to version 0.10.0.1550589094.e2ae17d:
  * move to python3
  * add python 3.6 and 3.7 to testing
  * added logging for better debugging changesgenerate
  * raise exception if no changesauthor given
  * removed python 2.6 from travis
* Fri Feb  1 2019 FSchreiner@suse.com
- Update to version 0.9.5.1548407358.b62685b:
  * Stop using @opensuse.org addresses to indicate a missing address
  * move argparse dep to -common package
  * allow submodule and ssl options in appimage
  * sync spec file as used in openSUSE:Tools project
* Mon Dec 17 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1545082095.8dbc95f:
  * [dist] fix service files installation in Makefile
* Mon Dec 17 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1545064321.5c10ac0:
  * check encoding problems for svn and print proper error msg
  * added new param '--locale'
  * separate service file installation in GNUmakefile
  * added glibc as Recommends in spec file
  * cleanup for broken svn caches
  * another fix for unicode problem in obs_scm
* Thu Dec  6 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1544099104.f52adb7:
  * Final fix for unicode in filenames
  * Another attempt to fix unicode filenames in prep_tree_for_archive
* Wed Dec  5 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1544015491.08dd948:
  * Another attempt to fix unicode filenames in prep_tree_for_archive
* Mon Dec  3 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1543865445.4e2fbad:
  * fix bug with unicode filenames in prep_tree_for_archive
  * reuse _service*_servicedata/changes files from previous service runs
* Fri Nov 30 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1543588452.b19491f:
  * fix problems with  unicode characters in commit messages for changeloggenerate
* Thu Nov 29 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1543502111.e576bd6:
  * fix encoding issues if commit message contains utf8 char
* Wed Nov 28 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1543424658.8740ef1:
  * revert encoding for old changes file
* Wed Nov 28 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1543418966.30359e4:
  * change pylint/flake8 back to 2.7 for now
  * remove hardcoded utf-8 encodings
* Thu Nov 22 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.5.1542905297.a6e346a:
  * make code python3 ready
  * Add support for extract globbing
* Wed Sep 26 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.4.1537959361.56833cb:
  * enable flake8 in hound
  * cleanup for pylint and flake8
  * split pylint2 in GNUmakefile
  * fix check for "--reproducible"
  * create reproducible obscpio archives
  * fix flake warning
* Tue Sep 25 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.3.1537869751.51a17c5:
  * fix regression from 44b3bee
  * Support also SSH urls for Git
* Mon Sep 24 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.2.1537788075.fefaa74:
  * fix CVE-2018-12473 (bsc#1105361)
  * fix CVE-2018-12474 (bsc#1107507)
  * fix CVE-2018-12476 (bsc#1107944)
  * check name/version option in obsinfo for slashes
  * check url for remote url
  * check symlinks in subdir parameter
  * check filename for slashes
  * disable follow_symlinks in extract feature
* Wed Sep 19 2018 adrian@suse.de
- switch to obs_scm for this package
* Wed Sep 19 2018 adrian@suse.de
- Update to version 0.9.1.1537341862.5348694:
  * run download_files in appimage and snapcraft case
  * check --extract file path for parent dir
  * Fix parameter descriptions
* Fri Aug 24 2018 adrian@suse.de
- Update to version 0.9.1.1534504824.0732756:
  * changed os.removedirs -> shutil.rmtree
  * Adding information regarding the *package-metadata* option for the *tar* service The tar service is highly useful in combination with the *obscpio* service. After the fix for the metadata for the latter one, it is important to inform the users of the *tar* service that metadata is kept only if the flag *package-metadata* is enabled. Add the flag to the .service file for mentioning that.
  * Allow metadata packing for CPIO archives when desired As of now, metadata are always excluded from *obscpio* packages. This is because the *package-metadata* flag is ignored; this change (should) make *obscpio* aware of it.
* Tue Jul  3 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.1.1530616709.1329314:
  * improve handling of corrupt git cache directories
  * only do git stash save/pop if we have a non-empty working tree (#228)
  * sort imports
  * don't allow DEBUG_TAR_SCM to change behaviour (#240)
  * add stub user docs in lieu of something proper (#238)
  * [dist] fix build for distros not yet supporting Recommends tag
  * Remove clone_dir if clone fails
  * python-unittest2 is only required for the optional make check
  * move python-unittest2 dep to test suite only part (submission by olh)
* Thu Apr 19 2018 fschreiner@suse.de
- Update to version v0.9.0.1523267117.de861d8:
  * Removing redundant pass statement
  * fixing indentation warnings from flake8
  * fixing flake8 warnings, missing imports
  * missing import for logging functions.
  * [backend] Adding http proxy support
* Fri Apr 13 2018 olaf@aepfle.de
- python-unittest2 is only required for the optional make check
* Fri Mar  9 2018 opensuse-packaging@opensuse.org
- Update to version 0.8.0.1520581079.e26b0ae:
  * make installation of scm's optional
  * add a lot more detail to README
  * Git clone with --no-checkout in prepare_working_copy
  * Refactor and simplify git prepare_working_copy
  * Cleanup flake8 checks
  * Only use current dir if it actually looks like git (Fixes #202)
  * reactivate test_obscpio_extract_d
  * fix broken test create_archive
  * fix broken tests for broken-links
  * changed PREFIX in Gnumakefile to /usr
  * new cli option --skip-cleanup
  * fix for broken links
  * fix reference to snapcraft YAML file
  * fix docstring typo in TarSCM.scm.tar.fetch_upstream
  * acknowledge deficiencies in dev docs
  * wrap long lines in README
* Wed Oct 11 2017 adrian@suse.de
- Update to version 0.8.0.1507129410.0cb2d44:
  * mention _none_ version string for people who need it for kiwi root archives for example
  * git: Support url change
  * change ordering so that latest change is on top
  * also override timestamps of files in cpio
  * Sort cpio file list
  * [dist] fix spec file py_compile for fedora
  * Sort tar file list
* Wed Jul 12 2017 opensuse-packaging@opensuse.org
- Update to version 0.8.0.1499787575.2419460:
  * [test] refactor of fake classes
  * [bugfix] fix UnboundLocalError: local variable 'parent_tag'
* Tue Jul 11 2017 opensuse-packaging@opensuse.org
- Update to version 0.8.0.1499787575.2419460:
  * [dist] changed to %%py_compile in spec file
  * [bugfix] fixes issue #173
  * [bugfix] Decoupled self.scm from class name in TarSCM/scm/*
  * [lint] make tests/unittestcases.py flake8 ready
  * [lint] more fixes for pylint readiness
  * [lint] refactor unittestcases.py
  * [test] increase cov for TarSCM.archive from 61%% to 92%%
  * [doc] added comment to --use-obs-scm
  * [test] refactor of fake classes
  * [bugfix] fix UnboundLocalError: local variable 'parent_tag'
* Sun Jul  9 2017 adrian@suse.de
- hotfix runtime of obs_scm
* Sat Jul  1 2017 opensuse-packaging@opensuse.org
- Update to version 0.8.0.1498846582.8799787:
  * fix for gh issue #169
  * new version placeholder for empty version string
  * fix for bzr locale problem in testsuite
  * pylint and flake8 in testsuite for better code quality
  * code cleanup to be more pylint and flake8 compatible
* Mon Jun 19 2017 adrian@suse.de
- Update to version 0.7.0.1497261741.b1aa4cb:
  * Move spec file to git
* Wed Jun  7 2017 adrian@suse.de
- Update to version 0.7.0.1496831936.d960322:
  * fix for nonexistant build section in appimage.yml
  * more documentation for README.md
  * Update control
* Wed Jun  7 2017 adrian@suse.de
- add python-yaml for debian distros
* Thu May 11 2017 marco.strigl@suse.com
- added Requires: python2 for Fedora >= 25
* Tue Apr 18 2017 fvogt@suse.com
- Only BuildRequire packages needed for testsuite if the testsuite
  is enabled
* Thu Apr 13 2017 adrian@suse.de
- Update to version 0.7.0.1492101301.747de50:
  * skip broken tests temporarily
* Thu Apr 13 2017 adrian@suse.de
- Update to version 0.7.0.1492095435.eda090e:
  * revision, repodir and repocachedir as attribute for TarSCM.<scm>
  * new class TarSCM.cli to make testing easier
  * testing script name more reliable
  * fixed arguments for singletask in case of snapcraft
  * refactored snapcraft code + first tests for snapcraft
  * added testcase for snapcraft finalize
  * split classes into several files
  * track module dependencies in requirements.txt
  * use unittest2 in Python 2.6
  * more testing for TarSCM.tasks
  * clone_dir/repodir/arch_dir(tar_dir)/args now attributes of scm objects
  * test case for save_run
  * major refactor of git cache handling
  * consolidation of archive.obscpio and archive.tar parameters
  * next test cases
  * unset CACHEDIRECTORY env variable in unit tests
  * update atime/mtime of repocachedir if already exists
  * prevent key errors when $HOME is not set
  * fix PEP8 problems and reenable PEP8 testing
  * keep checkout while running with osc
  * fix local checkout when running in osc
  * force remove of files while 'make clean'
  * fix: also exclude directories when called .git
  * fix problems with generatechanges when ~/.obs/tar_scm exists
  * initial appimage support
  * Provide version rewrite using a regex pattern and replacement.
  * new parameter --match-tag to filter tags
  * keep .gitlab/.github directories
* Thu Apr 13 2017 adrian@suse.de
- Update to version 0.7.0.1491998613.3890456:
  * refactor of detect_changes into classes
  * url as attribute of TarSCM.scm
  * run_cmd and safe_run moved into class helpers
  * combine os.path.join statement
  * refactoring fetch_upstream to be part of TarSCM.scm
  * new classes for archives
  * common method 'get_current_commit' to get rid of exception for git
  * refactored detect_changes to get rid of changesgenerate exception
  * get_repocachedir -> TarSCM.scm
  * Add description to the README.md file
* Wed Apr 12 2017 adrian@suse.de
- split services into own rpms
* Fri Mar 24 2017 adrian@suse.de
- Update to version 0.7.0.1490358243.8de854e:
  * keep .gitlab/.github directories
* Thu Mar 23 2017 adrian@suse.de
- Update to version 0.7.0.1490263157.682db30:
  * Provide version rewrite using a regex pattern and replacement.
  * initial appimage support
  * make pep8 happy again
  * test cases for version rewrite
  * new parameter --match-tag to filter tags
* Tue Feb 28 2017 dimstar@opensuse.org
- Replayce python-yaml Requires/Buildrequires with python-PyYAML,
  which is actually its correct name.
* Tue Jan 10 2017 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1484082405.7671be8:
  * fix problems with generatechanges when ~/.obs/tar_scm exists
* Wed Dec 14 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1481203567.804351a:
  * fix: also exclude directories when called .git
* Wed Dec  7 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1480953937.a4b8b09:
  * fix local checkout when running in osc
  * force remove of files while 'make clean'
* Thu Nov 24 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1480000004.4027270:
  * fixed pip8 problems
  * keep checkout while running with osc
* Fri Nov  4 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1478249268.e162c66:
  * prevent key errors when $HOME is not set
* Sun Oct 30 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1477858520.51a62fb:
  * added locking for cachedir in jailed mode
  * removed setup_tracking_branches and '--dissociate'
  * inital version of TarSCM classes
  * scm_object generation moved to singletask
  * FETCH_UPSTREAM_COMMANDS into classes
  * moved update_cache_* to classes
  * moved detect_version into classes and refactored calls of get_timestamp_*
  * moved get_timestamp functions into scm classes
  * git_ref_exists -> TarSCM.git._ref_exists
  * fetch_upstream_git_submodules -> fetch_submodules to get rid of exceptions for git
  * just moved some functions for better overview
  * refactor of detect_changes into classes
  * url as attribute of TarSCM.scm
  * run_cmd and safe_run moved into class helpers
  * combine os.path.join statement
  * refactoring fetch_upstream to be part of TarSCM.scm
  * new classes for archives
  * common method 'get_current_commit' to get rid of execption for git
  * refactored detect_changes to get rid of changesgenerate exception
  * get_repocachedir -> TarSCM.scm
  * revision, repodir and repocachedir as attribute for TarSCM.<scm>
  * new class TarSCM.cli to make testing easier
  * testing script name more reliable
  * fixed arguments for singletask in case of snapcraft
  * refactored snapcraft code + first tests for snapcraft
  * added testcase for snapcraft finalize
  * split classes into serveral files
  * more testing for TarSCM.tasks
  * clone_dir/repodir/arch_dir(tar_dir) now attributes of scm objects
  * test case for save_run
  * major refactor of git cache handling
  * consolidation of archive.obscpio and archive.tar parameters
  * next test cases
  * sytnax fix for "tar" service
  * fixed tests for tar
  * unset CACHEDIRECTORY env variable in unit tests
  * update atime/mtime of repocachedir if already exists
* Sun Oct 30 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1474270818.3e05f80:
  * 
* Thu Oct 27 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.0.1477567374.d44d677:
  * use '--dissociate' for git if package-meta is set
  * added locking for cachedir in jailed mode
  * removed setup_tracking_branches and '--dissociate'
  * inital version of TarSCM classes
  * scm_object generation moved to singletask
  * FETCH_UPSTREAM_COMMANDS into classes
  * moved update_cache_* to classes
  * moved detect_version into classes and refactored calls of get_timestamp_*
  * moved get_timestamp functions into scm classes
  * git_ref_exists -> TarSCM.git._ref_exists
  * fetch_upstream_git_submodules -> fetch_submodules to get rid of exceptions for git
  * just moved some functions for better overview
  * refactor of detect_changes into classes
  * url as attribute of TarSCM.scm
  * run_cmd and safe_run moved into class helpers
  * combine os.path.join statement
  * refactoring fetch_upstream to be part of TarSCM.scm
  * new classes for archives
  * common method 'get_current_commit' to get rid of execption for git
  * refactored detect_changes to get rid of changesgenerate exception
  * get_repocachedir -> TarSCM.scm
  * revision, repodir and repocachedir as attribute for TarSCM.<scm>
  * new class TarSCM.cli to make testing easier
  * testing script name more reliable
  * fixed arguments for singletask in case of snapcraft
  * refactored snapcraft code + first tests for snapcraft
  * added testcase for snapcraft finalize
  * split classes into serveral files
  * more testing for TarSCM.tasks
  * clone_dir/repodir/arch_dir(tar_dir) now attributes of scm objects
  * test case for save_run
  * major refactor of git cache handling
  * consolidation of archive.obscpio and archive.tar parameters
  * next test cases
  * sytnax fix for "tar" service
* Thu Oct 27 2016 adrian@suse.de
- Update to version 0.7.0.1476904507.e88eed1:
  * fixed arguments for singletask in case of snapcraft
  * refactored snapcraft code + first tests for snapcraft
  * added testcase for snapcraft finalize
  * split classes into serveral files
  * more testing for TarSCM.tasks
  * clone_dir/repodir/arch_dir(tar_dir) now attributes of scm objects
  * test case for save_run
  * major refactor of git cache handling
  * consolidation of archive.obscpio and archive.tar parameters
  * next test cases
* Thu Sep 15 2016 adrian@suse.de
- Update to version 0.6.1.1473925745.c5264bb:
  * jailed mode for docker integration
  * added setup of remote branches in jailed mode
  * new handling for remote/local branches when caching
  * fix permission problem of .changes files when running jailed in docker
  * fix problem with outdated git refs in cache
* Wed Aug 31 2016 adrian@suse.de
- Update to version 0.6.1.1472657181.ff9a5ca:
  * make yaml dependency optional for travis
  * Add an option 'master' to submodules to fetch the latest mater branch.
  * tar_scm.py: Always use an absolute path for the 'output' directory
  * do not set files back to 1970...
  * transfer mtime via obsinfo
  * create needed sub directories for cache handling
  * prefer local cache directory
  * - weak dependency to mercurial for debian
  * add python-dateutil require for debian
  * testing on debian is broken atm
* Wed Aug 31 2016 adrian@suse.de
- Update to version 0.6.1.1472656157.58c52d8:
  * make yaml dependency optional for travis
  * Add an option 'master' to submodules to fetch the latest mater branch.
  * tar_scm.py: Always use an absolute path for the 'output' directory
  * do not set files back to 1970...
  * transfer mtime via obsinfo
  * create needed sub directories for cache handling
  * prefer local cache directory
  * - weak dependency to mercurial for debian
  * add python-dateutil require for debian
  * testing on debian is broken atm
* Wed Aug 31 2016 adrian@suse.de
- Update to version 0.6.1.1472655284.4930b81:
  * add python-dateutil require for debian
  * testing on debian is broken atm
* Wed Aug 31 2016 adrian@suse.de
- fix debian builds
* Wed Aug 31 2016 adrian@suse.de
- Update to version 0.6.1.1472636708.355b59a:
  * fix some more merge regressions
  * pep8 fixes/workarounds
  * make yaml dependency optional for travis
  * Add an option 'master' to submodules to fetch the latest mater branch.
  * tar_scm.py: Always use an absolute path for the 'output' directory
  * do not set files back to 1970...
  * transfer mtime via obsinfo
  * create needed sub directories for cache handling
  * prefer local cache directory
  * - weak dependency to mercurial for debian
* Fri Aug 19 2016 adrian@suse.de
- Update to version 0.6.1.1471594222.d257927:
  * prefer local cache directory
  * jailed mode for docker integration
  * added setup of remote branches in jailed mode
  * new handling for remote/local branches when caching
- cache handling will be refactored to have only one implementation
  in future.
* Wed Jul 27 2016 adrian@suse.de
- fix mtime handling
* Wed Jul 27 2016 adrian@suse.de
- Update to version 0.6.0.1469628830.67456b7:
  * pep8 fixes/workarounds
  * make yaml dependency optional for travis
  * Add an option 'master' to submodules to fetch the latest mater branch.
  * do not set files back to 1970...
  * transfer mtime via obsinfo
  * create needed sub directories for cache handling
* Thu Jul  7 2016 adrian@suse.de
- update to official version 0.6.0
  (latest package became official)
* Thu Jul  7 2016 adrian@suse.de
- Update to version 0.6.0.1467889501.49c9462:
  + very first obs_scm implementation
  + allow extracting of (spec) files
  + allow to include local changes when using "obs_scm" service via local osc commands.
  + make obsinfo parameter for tar service optional
  + support filtering on creation of cpio archives
  + - add debian provides
  + - make cleaning message a debug message
  + report error when specified revision got not found
  + add snapcraft.yaml support
  + merge upstream
  + minor cleanup
  + fix typo, wrong file name of new snapcraft.yaml
  + fix some more merge regressions
  + pep8 fixes/workarounds
  + make yaml dependency optional for travis
* Fri Jul  1 2016 adrian@suse.de
- added snapcraft support via own service
* Wed Jun 29 2016 adrian@suse.de
- Update to version 0.6.0~pre.1467126663.ec976d1:
  * Allow to manually specify a base for @TAG_OFFSET@
  * - make cleaning message a debug message
  * Honour "subdir" param for changesgenerate
  * report error when specified revision got not found
  * Extend fixture to create commits with a specific timestamp
  * Use commit timestamp as mtime for files and directories in tarball
  * Workaround bug in Mercurial localdate filter
  * fix breakage from conflict of #63 and #85
  * Provide test for git tag fetching
  * Add ability to generate changes file when using svn
  * add snapcraft.yaml support
* Tue Apr 26 2016 adrian@suse.de
- Update to version 0.6.0~pre.1461678268.e8b5d73:
  * fix TESTING.md link in CONTRIBUTING.md
  * Use correct level 2 bullet point (*)
  * very first obs_scm implementation
  * allow extracting of (spec) files
  * allow to include local changes when using "obs_scm" service via local osc commands.
  * make obsinfo parameter for tar service optional
  * support filtering on creation of cpio archives
  * - add debian provides
* Tue Apr 26 2016 adrian@suse.de
- add debian provides
* Fri Apr 15 2016 adrian@suse.de
- fix dependency on SLE 11 to python-argparse
* Mon Apr 11 2016 mpluskal@suse.com
- Correctly reference patch in previous entry
* Mon Apr 11 2016 adrian@suse.de
- Update to version 0.6.0~pre.1460377105.35a4ea4:
  * support filtering on creation of cpio archives
* Fri Apr  8 2016 adrian@suse.de
- Update to version 0.6.0~pre.1460098798.dda5411:
  + make obsinfo parameter for tar service optional
* Thu Apr  7 2016 adrian@suse.de
- Update to version 0.6.0.1460017418.4e4b2d6:
  + Correct error message about lack of git tags
  + GNUmakefile: Use default python in $PATH unless it is a python 3.
  + fix TESTING.md link in CONTRIBUTING.md
  + Use correct level 2 bullet point (*)
  + very first obs_scm implementation
  + allow extracting of (spec) files
  + allow to include local changes when using "obs_scm" service via local osc commands.
- building this pre-version currently from private branch
  as discussed with Adam
* Wed Jul  8 2015 bwiedemann@suse.com
- only require git-core to not pull in git-web and gitk
* Wed Jun 24 2015 hib@hiberis.nl
- Fix build on Ubuntu by disabling mercurial tests
  * 0001-Debianization-disable-running-mercurial-tests.patch
* Mon Jun 22 2015 hib@hiberis.nl
- Update to version 0.5.3.1434983686.0b4ce51:
  + Add missing extension parameter to service file
  + Fix build on Debian 7.0/8.0
* Mon Jun  1 2015 aspiers@suse.com
- Update to version 0.5.3.1433158390.b0e72e1:
  + use the same Python interpreter for testing tar_scm
  + Split up the steps of git cloning and submodule initialization
  + fix Makefile test runner for Debian
* Wed May 27 2015 aspiers@suse.com
- Update to version 0.5.2.1432717816.cff60cf:
  + be explicit about python2, python may be python3
  + Fix newline at the end of @PARENT_TAG@
  + Fix Mercurial version format strings in unittest
  + Refactoring of package metadata regex matching
  + Refactor resetting of uid/gid so that it is reusable
  + Fix handling of --include option
  + Fix handling of --exclude option
  + Refactor subdir handling of tarchecker's to prevent code duplication
  + ignore PEP8's E731 check for lambdas
  + PEP8 E402 fix: set PYTHONPATH outside code
  + add @TAG_OFFSET@ support in versionformat for git
  + fix inconsistencies in tar_scm.service
  + - fix .service file syntax (OBS 2.6.1 is checking now)
  + mention need to set PYTHONPATH when running tests
  + keep STDERR separate
  + don't allow --subdir to wander outside repo (bsc#927120, #71)
* Wed Mar 18 2015 adrian@suse.de
- Update to version 0.5.1.1426664483.de67b88:
  + be explicit about python2, python may be python3
  + Fix newline at the end of @PARENT_TAG@
  + Fix Mercurial version format strings in unittest
  + Refactoring of package metadata regex matching
  + Refactor resetting of uid/gid so that it is reusable
  + Fix handling of --include option
  + Fix handling of --exclude option
  + Refactor subdir handling of tarchecker's to prevent code duplication
  + ignore PEP8's E731 check for lambdas
  + PEP8 E402 fix: set PYTHONPATH outside code
  + add @TAG_OFFSET@ support in versionformat for git
  + fix inconsistencies in tar_scm.service
  + - fix .service file syntax (OBS 2.6.1 is checking now)
* Wed Oct  8 2014 aspiers@suse.com
- Update to version 0.5.0.1412769870.6cda976:
  + change default git versionformat to %%ct.%%h
  + fix changes generation when version is blank
  + lots of refactoring
  + add info and caveats about data persisting between tests
  + gittests: give default author test a unique name
* Sun Oct  5 2014 aspiers@suse.com
- Update to version 0.4.2.1412467141.df3329e.  Many changes,
  including:
  + Retrieve tags for a cached git repo
  + Add PEP8 checking everywhere
  + Significantly improved tests
  + Fixed checkout of a hg url that ends with a trailing slash
  + Fix Debian build dependencies for python
  + Change Debian package format to 3.0 (native)
  + Install into /usr on Debian
  + Honor submodules=disable as before (fixes #38)
  + Fix directory name of repository clone
  + Fix handling of symbolic links
  + Fix crash when changesrevision <param> is missing
  + Improved usage text
  + Store git and hg hashes in full
  + Fix crash during copy of _servicedata
  + Fix format of new changes to match old shell tar_scm
  + Fix bug when temp file is on a different filesystem
  + Fix change generation bug introduced by Python rewrite
  + Fix retrieval of email address from ~/.oscrc
  + Refactor changesgenerate code
* Tue Sep  9 2014 jblunck@infradead.org
- Update to version 0.4.0.1410288598.7f38281:
  + Python rewrite of tar_scm
  + Make pep8 happy (except for regex in tar_scm:299)
  + Address some feedback from pylint
  + make Python version PEP8-compliant
  + Let Travis execute pep8
  + Strip newline ('\n') characters from safe_run output in detect_version()
  + Make potentially long-running tasks print output in real-time
  + Improve efficiency of stdout handling in safe_run()
  + Release obs-service-tar_scm 0.4.0
* Wed Jul  9 2014 jblunck@infradead.org
- Update to version 0.3.2.1404723797.745a470:
  + Initial debianization
  + switch git submodule versions correctly
  + add some basic documentation to the tests
  + split off info into TESTING.md
  + add CONTRIBUTING.md
  + improve formatting
  + whitelist accepted chars in arguments.
  + Correct/update install information
  + Reverse changes lines again with tac
* Wed Dec 11 2013 speilicke@suse.com
- Update to version 0.3.2.1386694317.b85b342:
  + Fix adding to already existing _servicedata case
  + Don't reverse changes lines with 'tac'
  + Fix Python FutureWarning about comparison with None
  + Improve description of the versionformat parameter.
- Enable changes generation
* Tue Nov 19 2013 adrian@suse.de
- Bump version to 0.3.2
  * changes file generation support written by Sascha
* Wed Oct 30 2013 adrian@suse.de
- Bump version to 0.3.1
  * do not execute tar base file name
* Fri Aug  2 2013 aspiers@suse.com
- Bump version to 0.3.0 and include git timestamp / SHA1 in version.
- Update to latest git (9de0986):
  + add git submodule update test
  + extract submodule_path() method
  + allow git commands to run from cwd
  + rename opts to args
  + annotate cwd
  + ensure all scm invocations succeed when expected
  + record revisions per repository path
  + allow creation of git submodules
  + Fixtures.create_commits(): add repository path parameter
  + GitFixtures.create_repo(): add repository path parameter
  + fix hg tests when run in timezone east of UTC
  + add hint about running tests quicker
  + don't hardcode revision in helper method
  + quoting tweak
  + make test output more consistent
  + get line spacing right
  + Travis: also test with Python 2.6
  + tweak debugging for mv invocations
  + a bit more info on the test suite
  + leave temporary files behind on failure, for debugging
  + add some docstrings to a few of the more complex tests
  + make switching to a given git revision more robust
  + try to make test output a little easier to understand
  + improve README.md
  + switch README to markdown and add Travis build status icon
  + replace XML entities with dollar-curlies
  + Properly encode XML reserved entities (&,<,>)
  + add better revision description/documentation for git
  + We are still not allowed to have dashes inside version. Fix for mercurial.
  + allow-different-naming-schemes-for-resulting-tar-files
  + Fix breakage when LANG is not English (issue #8)
  + Make test.py executable
  + README: add information about the test suite
  + Don't rely on git error codes for "git describe", catch all
  + Better error handling for @PARENT_TAG@ expansion
  + the correct tag is 'param', 'parameter' won't work
  + Tell Travis where to find the tests
  + Cleanup testing tmp_dir afterwards
  + Add description for @PARENT_TAG@
  + Ignore .coverage
  + Move tests into sub-directory
  + Last change for some bonus points
  + Naa, typo
  + Update package database before installing dependencies
  + Add initial Travis-CI configuration
  + Add .gitignore file
  + Add test for @PARENT_TAG@
* Tue Dec  4 2012 saschpe@suse.de
- Pass --tags to "git describe" for @PARENT_TAG@
* Mon Dec  3 2012 saschpe@suse.de
- Disable testsuite on SLE_11_SP2 to fix build
* Mon Dec  3 2012 saschpe@suse.de
- Use upstream github repository and download via _service file
* Mon Dec  3 2012 saschpe@suse.de
- Add custom git versionformat extensions:
  + @PARENT_TAG@: Replaced by first tag that is reachable from the
    current commit (see 'git describe')
  Future custom additions could follow the @NAME@ scheme
* Thu Nov  1 2012 aspiers@suse.com
- Fix usage text for submodules option
* Mon Oct  1 2012 cthiel@suse.com
- change default versionformat from author date (%%at) to commiter date (%%ct)
  for git, to fix issues with cherry-picked commits resulting in decreased
  version
* Mon Sep 24 2012 jslaby@suse.com
- add --date=short to get_vesion of git and remove '-' chars
  by sed. This allows us to use %%ad as versionformat and
  have something like "20120916" as version instead of
  terrible Unix timestamps.
* Fri Jul 27 2012 aspiers@suse.com
- Prevent local users from appearing as user/group owner in
  generated tar files (thanks bmwiedemann for this)
* Tue Jul  3 2012 adrian@suse.de
- fix option for submodule update
* Sat Jun 30 2012 magist3r@gmail.com
- Fixed error with cache
* Sat Jun 30 2012 magist3r@gmail.com
- Added an option to disable git submodules
- Replaced --exclude=.$MYSCM with --exclude-vcs tar option
* Thu Jun 28 2012 magist3r@gmail.com
- Added support for git submodules
* Tue Jun  5 2012 saschpe@suse.de
- Re-iterating the last change once again, 'git rev-parse --verify $REV'
  will return false even if $REV is a normal branch upon first clone
  of the repo. Thus 'git fetch $URL +$REV:$REV" is run initially.
  However, the 'git checkout $REV' then fails because it's missing
  tracking information. Therefore, try a normal checkout first and fetch
  the specific $REV only when that fails (due to reasons described below).
* Thu May 24 2012 rohan.mcgovern@nokia.com
- Allow git revision to refer to revisions not available from a
  default clone/fetch (i.e. refs other than refs/heads/* or
  refs/tags/*)
* Mon Mar 19 2012 aspiers@suse.com
- Check that git pull succeeds
* Wed Feb 29 2012 aspiers@suse.com
- Remove accidental reference to keep-source parameter
  which was never pushed upstream (obsoleted by new cache).
* Thu Feb 16 2012 aspiers@suse.com
- When the cache is used, output location of repo in the cache
* Tue Feb 14 2012 aspiers@suse.com
- add new 'versionformat' option to determine how version is
  extracted via git show --pretty=...
- support caching of cloned repositories to speed up fetch
  from upstream
* Mon Feb 13 2012 aspiers@suse.com
- Add test suite
- Fix --subdir with --scm svn
- Fix --scm bzr
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Jan 24 2012 rschiele@gmail.com
- add new option to specify a subset of files/subdirectories to
  pack in the tar ball
* Tue Jan 24 2012 rschiele@gmail.com
- Checking out a specific revision cannot work when only the latest
  version is cloned.
* Thu Dec 29 2011 gollub@b1-systems.de
- make svn checkout --trust-server-cert option conditional, since
  this option is not supported by versions prior to subversion 1.6.
* Thu Dec 29 2011 gollub@b1-systems.de
- Trim user prefix from tarball filename.
  This enables tar_scm service to be used with git and ssh transport
  (in conjuction with a passphrase less ssh-pubkey). Example Git URL:
  git@gitrepo.tld:foobar.git
* Thu Dec 29 2011 gollub@b1-systems.de
- git 1.6.x and very likely other version only support
  "show --pretty=format:%%at" as parameter with "format:" prefix.
  git show --pretty=%%at is also support by recent git versions.
* Mon Aug 29 2011 adrian@suse.de
- make it possible to create tar balls without version tag (#714542)
* Fri Aug 26 2011 adrian@suse.de
- support old tar bar lookup also for OBS 2.3 bs_service using .old/ directory
* Fri Aug 26 2011 adrian@suse.de
- drop broken code for same-commit-detection as suggested by Markus
* Thu Aug 25 2011 markus.lehtonen@linux.intel.com
- history-depth parameter: use hackish depth=999999999 if "full" is
  given so that a shallow clone will be fully deepened if the
  _service file is changed. Also, fix git clone cmd line (remove
  a pair of quotes that cause problems).
* Thu Aug 25 2011 adrian@suse.de
- add support for (git) checkout depth, original patch by
  Markus Lehtonen <markus.lehtonen@linux.intel.com>
* Wed Aug 17 2011 adrian@suse.de
- make packaging of meta data optional to reduce tar ball size
* Fri Aug 12 2011 adrian@suse.de
- fix exclude expansion
* Mon Jun 20 2011 cthiel@novell.com
- add support for bzr
* Tue Mar 22 2011 ammler@openttdcoop.org
- Fix: recompressed tars were never reused
- cleanup mercurial commands
* Tue Feb  8 2011 adrian@suse.de
- always trust svn server certificate. We don't have a secure handling
  for it anyway. Trust needs to established via extra service.
* Wed Jan 12 2011 adrian@suse.de
- fix subdir usage for git
* Thu Dec 30 2010 adrian@suse.de
- add option exclude files/directories when creating the tar ball
- git clone runs now with --depth 1 option
* Wed Dec  8 2010 wr@rosenauer.org
- support mercurial repositories
* Wed Oct 20 2010 reddwarf@opensuse.org
- Fix --filename parameter use
* Fri Sep  3 2010 adrian@suse.de
- initial version to checkout/update svn or git repos and create a tar
